matminer.figrecipes package — matminer 0.1.3 documentation

# matminer.figrecipes package

## Subpackages

- matminer.figrecipes.matplotlib package
  - Subpackages
    - matminer.figrecipes.matplotlib.examples package
      - Submodules
      - matminer.figrecipes.matplotlib.examples.heatmap_examples module
      - matminer.figrecipes.matplotlib.examples.xyscatter_examples module
      - Module contents
  - Submodules
  - matminer.figrecipes.matplotlib.plots module
  - Module contents
- matminer.figrecipes.plotly package
  - Submodules
  - matminer.figrecipes.plotly.make_plots module
  - Module contents

## Module contents